@@ -19,7 +19,7 @@ def _get_newest_index(api) -> int:
     logger = DefaultLogger('api', api.config.log_level)
 
     last_screen = api.connect_core.get_screen_queue()[-1]
-    # print(last_screen)
+
     last_screen_list = last_screen.split('\n')
     last_screen_list = last_screen_list[3:]
     last_screen_list = '\n'.join([x[:9] for x in last_screen_list])
@@ -106,10 +106,14 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
         target_list = [
             connect_core.TargetUnit('沒有文章...', log_level=LogLevel.DEBUG, break_detect=True),
             connect_core.TargetUnit(screens.Target.InBoard, log_level=LogLevel.DEBUG, break_detect=True),
-            connect_core.TargetUnit(screens.Target.InBoardWithCursor, log_level=LogLevel.DEBUG, break_detect=True),
             connect_core.TargetUnit(screens.Target.MainMenu_Exiting,
                                     exceptions_=exceptions.NoSuchBoard(api.config, board)),
         ]
+
+        if search_type != data_type.SearchType.NOPE:
+            target_list.insert(2, connect_core.TargetUnit(screens.Target.InBoardWithCursor, log_level=LogLevel.DEBUG,
+                                                          break_detect=True))
+
         index = api.connect_core.send(cmd, target_list)
         if index < 0:
             # OriScreen = api.connect_core.getScreenQueue()[-1]
@@ -149,11 +153,9 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
             current_capacity, _ = _api_util.get_mailbox_capacity(api)
             last_screen = api.connect_core.get_screen_queue()[-1]
             cursor_line = [x for x in last_screen.split('\n') if x.strip().startswith(api.cursor)][0]
-            # print('---->', cursor_line)
+
             list_index = int(re.compile('(\d+)').search(cursor_line).group(0))
 
-            # print('----> list_index', list_index)
-            # print('----> current_capacity', current_capacity)
             if search_type == 0 and search_list is None:
                 if list_index > current_capacity:
                     newest_index = list_index
@@ -164,6 +166,7 @@ def get_newest_index(api, index_type: data_type.NewIndex, board: [str | None] =
 
             return newest_index
 
+        newest_index = 0
         for i in range(3):
             index = api.connect_core.send(
                 cmd,
